@@ -212,7 +212,7 @@ Zarafa.plugins.desktopnotifications.DesktopNotificationsPlugin = Ext.extend(Zara
 Zarafa.onReady(function() {
 	container.registerPlugin(new Zarafa.core.PluginMetaData({
 		name : 'desktopnotifications',
-		displayName : _('Desktop Notifications Plugin'),
+		displayName : dgettext('plugin_desktopnotifications', 'Desktop Notifications Plugin'),
 		about : Zarafa.plugins.desktopnotifications.ABOUT,
 		pluginConstructor : Zarafa.plugins.desktopnotifications.DesktopNotificationsPlugin
 	}));
@@ -291,7 +291,7 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsCategory =
 		config = config || {};
 
 		Ext.applyIf(config, {
-			title : _('Desktop Notifications'),
+			title : dgettext('plugin_desktopnotifications', 'Desktop Notifications'),
 			categoryIndex : 9996,
 			xtype : 'zarafa.settingsdesktopnotificationscategory',
 			iconCls : 'icon_desktopnotifications_settings',
@@ -340,7 +340,7 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsWidget = Ex
 		config = config || {};
 
 		Ext.applyIf(config, {
-			title : _('Desktop Notifications Settings Plugin'),
+			title : dgettext('plugin_desktopnotifications', 'Desktop Notifications Settings'),
 			xtype : 'zarafa.settingsdesktopnotificationswidget',
 			layout : {
 				// override from SettingsWidget
@@ -365,11 +365,11 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsWidget = Ex
 			items : [{
 				xtype : 'displayfield',
 				hideLabel : true,
-				value : _('For enabling desktop notifications we need permissions from the browser. (Only Chrome and Firefox are supported) ')
+				value : dgettext('plugin_desktopnotifications', 'For enabling desktop notifications we need permissions from the browser. (Only Chrome and Firefox are supported)')
 			}, {
 				xtype : 'button',
 				width : 200,
-				text : _('Request Permissions'),
+				text : dgettext('plugin_desktopnotifications', 'Request Permissions'),
 				handler : this.requestPermission,
 				scope : this,
 				hideLabel : true,
@@ -377,7 +377,7 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsWidget = Ex
 				style: 'margin-bottom: 6px;'
 			}, {
 				xtype : 'checkbox',
-				boxLabel : _('Enable desktop notifications for new mail'),
+				boxLabel : dgettext('plugin_desktopnotifications', 'Enable desktop notifications for new mail'),
 				name : 'zarafa/v1/main/notifier/info/newmail/value',
 				handler : this.onChangeCheckbox,
 				scope : this,
@@ -385,7 +385,7 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsWidget = Ex
 				ref : '../newMailNotificationsCheck'
 			}, {
 				xtype : 'checkbox',
-				boxLabel : _('Enable desktop notifications for reminders'),
+				boxLabel : dgettext('plugin_desktopnotifications', 'Enable desktop notifications for reminders'),
 				name : 'zarafa/v1/main/notifier/info/reminder/value',
 				handler : this.onChangeCheckbox,
 				scope : this,
@@ -394,7 +394,7 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsWidget = Ex
 			}, {
 				xtype: 'zarafa.compositefield',
 				plugins: [ 'zarafa.splitfieldlabeler' ],
-				fieldLabel: _('{A} Autohide desktop notification after second(s) {B}'),
+				fieldLabel: dgettext('plugin_desktopnotifications', '{A} Autohide desktop notification after second(s) {B}'),
 				labelWidth: 300,
 				combineErrors: false,
 				items: [{
