@@ -136,7 +136,7 @@ Zarafa.plugins.intranet.Intranet = Ext.extend(Zarafa.core.Plugin, {
 	{
 		var tabIndex;
 		Ext.each(container.getTabPanel().items.items, function(item, index){
-			if ( item.url===btn.url && item.title===btn.text ){
+			if (item.url === btn.site.url && item.title === btn.text) {
 				tabIndex = index;
 			}
 		});
