@@ -46,6 +46,10 @@
 		 */
 		private $userstores;
 
+		/**
+		 * @var array Cache for userentryid -> archive properties
+		 */
+		private $archivePropsCache;
 
 		/**
 		 * @var int Makes sure retrieveUserData is called only once
@@ -60,6 +64,7 @@
 			$this->session = false;
 			$this->ab = false;
 			$this->userstores = array();
+			$this->archivePropsCache = array();
 			$this->userDataRetrieved = false;
 		}
 
@@ -97,6 +102,22 @@
 			return $result;
 		}
 
+		/**
+		 * Get the user MAPI Object
+		 *
+		 * @param string $userEntryid The user entryid which is going to open. default is false.
+		 * @return object An user MAPI object.
+		 */
+		function getUser($userEntryid = false){
+			if($userEntryid === false) {
+				// get user entryid
+				$store_props = mapi_getprops($this->getDefaultMessageStore(), array(PR_USER_ENTRYID));
+				$userEntryid = $store_props[PR_USER_ENTRYID];
+			}
+			// open the user entry
+			return mapi_ab_openentry($this->getAddressbook(true), $userEntryid);
+		}
+
 		/**
 		* Get logged-in user information
 		*
@@ -119,11 +140,8 @@
 			$result = NOERROR;
 
 			try {
-				// get user entryid
 				$store_props = mapi_getprops($this->getDefaultMessageStore(), array(PR_USER_ENTRYID));
-
-				// open the user entry
-				$user = mapi_ab_openentry($this->getAddressbook(true), $store_props[PR_USER_ENTRYID]);
+				$user = $this->getUser($store_props[PR_USER_ENTRYID]);
 
 				// receive userdata
 				// TODO: 0x8C9E0102 represents an LDAP jpegPhoto and should get a named property PR_EMS_AB_THUMBNAIL_PHOTO
@@ -328,6 +346,24 @@
 			return array_key_exists("userimage",$this->session_info)? $this->session_info["userimage"]:false;
 		}
 
+		/**
+		 * Get currently disabled features for the user
+		 * @return array An disabled features list.
+		 */
+		function getDisabledFeatures()
+		{
+			$userProps = mapi_getprops($this->getUser(), array(PR_EC_DISABLED_FEATURES));
+			return isset($userProps[PR_EC_DISABLED_FEATURES]) ? $userProps[PR_EC_DISABLED_FEATURES] : [];
+		}
+
+		/**
+		 * @return boolean True if webapp is disabled feature else return false.
+		 */
+		function isWebappDisableAsFeature()
+		{
+			return array_search('webapp', $this->getDisabledFeatures()) !== false;
+		}
+
 		 /**
 		  * Magic method to get properties from the session_info. When a method of this class if called
 		  * and there is no method of this name defined this function will be called
@@ -569,9 +605,11 @@
 		 */
 		function getArchivedStores($userEntryid)
 		{
-			$ab = $this->getAddressbook();
-			$abitem = mapi_ab_openentry($ab, $userEntryid);
-			$userData = mapi_getprops($abitem, Array(PR_ACCOUNT, PR_EC_ARCHIVE_SERVERS));
+			if (!isset($this->archivePropsCache[$userEntryid])) {
+				$this->archivePropsCache[$userEntryid] = $this->getArchiveProps($userEntryid);
+			}
+
+			$userData = $this->archivePropsCache[$userEntryid];
 
 			$archiveStores = Array();
 			if(isset($userData[PR_EC_ARCHIVE_SERVERS]) && count($userData[PR_EC_ARCHIVE_SERVERS]) > 0){
@@ -603,6 +641,16 @@
 			return $archiveStores;
 		}
 
+		/**
+		 * @param String $userEntryid binary entryid of the user
+		 * @return Array Address Archive Properties of the user.
+		 */
+		private function getArchiveProps($userEntryid) {
+			$ab = $this->getAddressbook();
+			$abitem = mapi_ab_openentry($ab, $userEntryid);
+			return mapi_getprops($abitem, Array(PR_ACCOUNT, PR_EC_ARCHIVE_SERVERS));
+		}
+
 		/**
 		 * Get all the available shared stores
 		 *
@@ -611,31 +659,33 @@
 		function getOtherUserStore()
 		{
 			$otherusers = $this->retrieveOtherUsersFromSettings();
-			if(is_array($otherusers)) {
-				foreach($otherusers as $username=>$folder) {
-					if(is_array($folder) && !empty($folder)) {
-						try {
-							$user_entryid = mapi_msgstore_createentryid($this->getDefaultMessageStore(), $username);
+			foreach($otherusers as $username=>$folder) {
+				if (isset($this->userstores[$username])) {
+					continue;
+				}
 
-							$this->openMessageStore($user_entryid, $username);
-							$this->userstores[$username] = $user_entryid;
+				if(is_array($folder) && !empty($folder)) {
+					try {
+						$user_entryid = mapi_msgstore_createentryid($this->getDefaultMessageStore(), $username);
 
-							// Check if an entire store will be loaded, if so load the archive store as well
-							if(isset($folder['all']) && $folder['all']['folder_type'] == 'all'){
-								$this->getArchivedStores($this->resolveStrictUserName($username));
-							}
-						} catch (MAPIException $e) {
-							if ($e->getCode() == MAPI_E_NOT_FOUND) {
-								// The user or the corresponding store couldn't be found,
-								// print an error to the log, and remove the user from the settings.
-								dump('Failed to load store for user ' . $username . ', user was not found. Removing it from settings.');
-								$GLOBALS["settings"]->delete("zarafa/v1/contexts/hierarchy/shared_stores/" . $username, true);
-							} else {
-								// That is odd, something else went wrong. Lets not be hasty and preserve
-								// the user in the settings, but do print something to the log to indicate
-								// something happened...
-								dump('Failed to load store for user ' . $username . '. ' . $e->getDisplayMessage());
-							}
+						$this->openMessageStore($user_entryid, $username);
+						$this->userstores[$username] = $user_entryid;
+
+						// Check if an entire store will be loaded, if so load the archive store as well
+						if(isset($folder['all']) && $folder['all']['folder_type'] == 'all'){
+							$this->getArchivedStores($this->resolveStrictUserName($username));
+						}
+					} catch (MAPIException $e) {
+						if ($e->getCode() == MAPI_E_NOT_FOUND) {
+							// The user or the corresponding store couldn't be found,
+							// print an error to the log, and remove the user from the settings.
+							dump('Failed to load store for user ' . $username . ', user was not found. Removing it from settings.');
+							$GLOBALS["settings"]->delete("zarafa/v1/contexts/hierarchy/shared_stores/" . $username, true);
+						} else {
+							// That is odd, something else went wrong. Lets not be hasty and preserve
+							// the user in the settings, but do print something to the log to indicate
+							// something happened...
+							dump('Failed to load store for user ' . $username . '. ' . $e->getDisplayMessage());
 						}
 					}
 				}
@@ -652,7 +702,7 @@
 		function resolveStrictUserName($username)
 		{
 			$storeEntryid = mapi_msgstore_createentryid($this->getDefaultMessageStore(), $username);
-			$store = mapi_openmsgstore($this->getSession(), $storeEntryid);
+			$store = $this->openMessageStore($storeEntryid, $username);
 			$storeProps = mapi_getprops($store, Array(PR_MAILBOX_OWNER_ENTRYID));
 			return $storeProps[PR_MAILBOX_OWNER_ENTRYID];
 		}
@@ -664,37 +714,53 @@
 		 */
 		function retrieveOtherUsersFromSettings()
 		{
-			$result = false;
-			$other_users = $GLOBALS["settings"]->get("zarafa/v1/contexts/hierarchy/shared_stores",null);
+			$other_users = $GLOBALS["settings"]->get("zarafa/v1/contexts/hierarchy/shared_stores", []);
 
-			if (is_array($other_users)){
-				$result = Array();
-				// Due to a previous bug you were able to open folders from both user_a and USER_A
-				// so we have to filter that here. We do that by making everything lower-case
-				foreach($other_users as $username=>$folders) {
-					// No folders are being shared, the store has probably been closed by the user,
-					// but the username is still lingering in the settings...
-					if (!isset($folders) || empty($folders)) {
-						continue;
-					}
+			$uppercaseUsers = array_filter(array_keys($other_users), function($string) {
+				return (bool) preg_match('/[A-Z]/', $string);
+			});
 
-					$username = strtolower($username);
-					if(!isset($result[$username])) {
-						$result[$username] = Array();
-					}
+			if ($uppercaseUsers) {
+				return $this->convertUpperCaseOtherUsersSettings($other_users);
+			}
 
-					foreach($folders as $type => $folder) {
-						if(is_array($folder)) {
-							$result[$username][$folder["folder_type"]] = Array();
-							$result[$username][$folder["folder_type"]]["folder_type"] = $folder["folder_type"];
-							$result[$username][$folder["folder_type"]]["show_subfolders"] = $folder["show_subfolders"];
-						}
-					}
+			return $other_users;
+		}
+
+
+		/*
+		 * Convert old settings to new settings format. Due to a
+		 * previous bug you were able to open folders from both user_a
+		 * and USER_A so we have to filter that here. We do that by
+		 * making everything lower-case
+		 * @param array $other_users the shared_stores settings
+		 * @return array Array of usernames of delegate stores
+		 */
+		private function convertUpperCaseOtherUsersSettings($other_users) {
+			$result = [];
+
+			foreach($other_users as $username=>$folders) {
+				// No folders are being shared, the store has probably been closed by the user,
+				// but the username is still lingering in the settings...
+				if (!isset($folders) || empty($folders)) {
+					continue;
 				}
 
-				$GLOBALS["settings"]->set("zarafa/v1/contexts/hierarchy/shared_stores", $result);
+				$username = strtolower($username);
+				if(!isset($result[$username])) {
+					$result[$username] = Array();
+				}
+
+				foreach($folders as $type => $folder) {
+					if(is_array($folder)) {
+						$result[$username][$folder["folder_type"]] = Array();
+						$result[$username][$folder["folder_type"]]["folder_type"] = $folder["folder_type"];
+						$result[$username][$folder["folder_type"]]["show_subfolders"] = $folder["show_subfolders"];
+					}
+				}
 			}
-			return $result;
+
+			$GLOBALS["settings"]->set("zarafa/v1/contexts/hierarchy/shared_stores", $result);
 		}
 
 		/**
@@ -744,6 +810,20 @@
 			return $this->userstores[$username];
 		}
 
+		/**
+		 * Get the username of the user store
+		 *
+		 * @param string $username The loginname of whom we want to full name.
+		 * @return string the display name of the user.
+		 */
+		function getDisplayNameofUser($username)
+		{
+			$user_entryid = $this->getStoreEntryIdOfUser($username);
+			$store = $this->openMessageStore($user_entryid, $username);
+			$props = mapi_getprops($store, array(PR_DISPLAY_NAME));
+			return str_replace('Inbox - ', '', $props[PR_DISPLAY_NAME]);
+		}
+
 		/**
 		 * Get the username of the owner of the specified store
 		 *
@@ -892,9 +972,14 @@
 				$subtreeEntryid = $storeProps[PR_IPM_SUBTREE_ENTRYID];
 			}
 
-			// Only searches one level deep, otherwise deleted contact folders will also be included.
 			$contactFolders = array();
-			$contactFolders = $this->getContactFolders($store, $subtreeEntryid, false);
+			try{
+				// Only searches one level deep, otherwise deleted contact folders will also be included.
+				$contactFolders = $this->getContactFolders($store, $subtreeEntryid, false);
+			}catch (Exception $e) {
+				return $contactFolders;
+			}
+
 			// Need to search all the contact-subfolders within first level contact folders.
 			$firstLevelHierarchyNodes = $contactFolders;
 			foreach ($firstLevelHierarchyNodes as $key => $firstLevelNode) {
@@ -946,5 +1031,17 @@
 
 			return mapi_table_queryallrows($contactFolderTable, array(PR_STORE_ENTRYID, PR_ENTRYID, PR_DISPLAY_NAME));
 		}
+
+		/**
+		 * Obtains server version from the PR_EC_SERVER_VERSION property.
+		 */
+		public function getServerVersion()
+		{
+			$props = mapi_getprops($this->getDefaultMessageStore(), array(PR_EC_SERVER_VERSION));
+			if (propIsError(PR_EC_SERVER_VERSION, $props) === MAPI_E_NOT_FOUND) {
+				return '';
+			}
+			return $props[PR_EC_SERVER_VERSION];
+		}
 	}
 ?>
