@@ -141,24 +141,19 @@
 				$properties["goid2"] = "PT_BINARY:PSETID_Meeting:0x23";
 				$properties["type"] = "PT_STRING8:PSETID_Meeting:0x24";
 				$properties["meetingrecurring"] = "PT_BOOLEAN:PSETID_Meeting:0x5";
-				$properties["unknown2"] = "PT_BOOLEAN:PSETID_Meeting:0xa";
 				$properties["attendee_critical_change"] = "PT_SYSTIME:PSETID_Meeting:0x1";
 				$properties["owner_critical_change"] = "PT_SYSTIME:PSETID_Meeting:0x1a";
 				$properties["meetingstatus"] = "PT_LONG:PSETID_Appointment:0x8217";
 				$properties["responsestatus"] = "PT_LONG:PSETID_Appointment:0x8218";
-				$properties["unknown6"] = "PT_LONG:PSETID_Meeting:0x4";
 				$properties["reply_time"] = "PT_SYSTIME:PSETID_Appointment:0x8220";
 				$properties["reply_name"] = "PT_STRING8:PSETID_Appointment:0x8230";
-				$properties["usetnef"] = "PT_BOOLEAN:PSETID_Common:0x8582";
 				$properties["recurrence_data"] = "PT_BINARY:PSETID_Appointment:0x8216";
 				$properties["reminderminutes"] = "PT_LONG:PSETID_Common:0x8501";
 				$properties["reminderset"] = "PT_BOOLEAN:PSETID_Common:0x8503";
 				$properties["flag_request"] = "PT_STRING8:PSETID_Common:0x8530";
 				$properties["flag_due_by"] = "PT_SYSTIME:PSETID_Common:0x8560";
-				$properties["sendasical"] = "PT_BOOLEAN:PSETID_Appointment:0x8200";
 				$properties["updatecounter"] = "PT_LONG:PSETID_Appointment:0x8201";                                     // AppointmentSequenceNumber
 				$properties["last_updatecounter"] = "PT_LONG:PSETID_Appointment:0x8203";                        // AppointmentLastSequence
-				$properties["unknown7"] = "PT_LONG:PSETID_Appointment:0x8202";
 				$properties["busystatus"] = "PT_LONG:PSETID_Appointment:0x8205";
 				$properties["intendedbusystatus"] = "PT_LONG:PSETID_Appointment:0x8224";
 				$properties["start"] = "PT_SYSTIME:PSETID_Appointment:0x820d";
@@ -270,9 +265,6 @@
 				$properties["goid"] = "PT_BINARY:PSETID_Meeting:0x3";
 				$properties["goid2"] = "PT_BINARY:PSETID_Meeting:0x23";
 
-				// Conflict properties
-				$properties["conflictitems"] = PR_CONFLICT_ITEMS;
-
 				// Propose new time properties
 				$properties["proposed_start_date"] = "PT_SYSTIME:PSETID_Appointment:0x8250";
 				$properties["proposed_end_date"] = "PT_SYSTIME:PSETID_Appointment:0x8251";
@@ -305,6 +297,61 @@
 			return $properties;
 		}
 
+		/**
+		 * Returns the properties for a recurrence in the listview.
+		 * @return array properties for a recurrence.
+		 */
+		function getRecurrenceProperties()
+		{
+			$this->Init();
+
+			if (!isset($this->mapping[$this->storeMapping]['recurrence'])) {
+				$properties = array();
+				$properties["entryid"] = PR_ENTRYID;
+				$properties["parent_entryid"] = PR_PARENT_ENTRYID;
+				$properties["message_class"] = PR_MESSAGE_CLASS;
+				$properties["icon_index"] = PR_ICON_INDEX;
+				$properties["subject"] = PR_SUBJECT;
+				$properties["display_to"] = PR_DISPLAY_TO;
+				$properties["importance"] = PR_IMPORTANCE;
+				$properties["sensitivity"] = PR_SENSITIVITY;
+				$properties["startdate"] = "PT_SYSTIME:PSETID_Appointment:0x820d";
+				$properties["duedate"] = "PT_SYSTIME:PSETID_Appointment:0x820e";
+				$properties["recurring"] = "PT_BOOLEAN:PSETID_Appointment:0x8223";
+				$properties["recurring_data"] = "PT_BINARY:PSETID_Appointment:0x8216";
+				$properties["busystatus"] = "PT_LONG:PSETID_Appointment:0x8205";
+				$properties["label"] = "PT_LONG:PSETID_Appointment:0x8214";
+				$properties["alldayevent"] = "PT_BOOLEAN:PSETID_Appointment:0x8215";
+				$properties["private"] = "PT_BOOLEAN:PSETID_Common:0x8506";
+				$properties["meeting"] = "PT_LONG:PSETID_Appointment:0x8217";
+				$properties["startdate_recurring"] = "PT_SYSTIME:PSETID_Appointment:0x8235";
+				$properties["enddate_recurring"] = "PT_SYSTIME:PSETID_Appointment:0x8236";
+				$properties["recurring_pattern"] = "PT_STRING8:PSETID_Appointment:0x8232";
+				$properties["location"] = "PT_STRING8:PSETID_Appointment:0x8208";
+				$properties["duration"] = "PT_LONG:PSETID_Appointment:0x8213";
+				$properties["responsestatus"] = "PT_LONG:PSETID_Appointment:0x8218";
+				$properties["reminder"] = "PT_BOOLEAN:PSETID_Common:0x8503";
+				$properties["reminder_minutes"] = "PT_LONG:PSETID_Common:0x8501";
+				$properties["recurrencetype"] = "PT_LONG:PSETID_Appointment:0x8231";
+				$properties["contacts"] = "PT_MV_STRING8:PSETID_Common:0x853a";
+				$properties["contacts_string"] = "PT_STRING8:PSETID_Common:0x8586";
+				$properties["categories"] = "PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords";
+				$properties["reminder_time"] = "PT_SYSTIME:PSETID_Common:0x8502";
+				$properties["commonstart"] = "PT_SYSTIME:PSETID_Common:0x8516";
+				$properties["commonend"] = "PT_SYSTIME:PSETID_Common:0x8517";
+				$properties["basedate"] = "PT_SYSTIME:PSETID_Appointment:0x8228";
+				$properties["timezone_data"] = "PT_BINARY:PSETID_Appointment:0x8233";
+				$properties["timezone"] = "PT_STRING8:PSETID_Appointment:0x8234";
+				$properties["flagdueby"] = "PT_SYSTIME:PSETID_Common:0x8560";
+				$properties["side_effects"] = "PT_LONG:PSETID_Common:0x8510";
+				$properties["hideattachments"] = "PT_BOOLEAN:PSETID_Common:0x8514";
+
+				$this->mapping[$this->storeMapping]['recurrence'] = getPropIdsFromStrings($this->store, $properties);
+			}
+
+			return $this->mapping[$this->storeMapping]['recurrence'];
+		}
+
 		/**
 		 * Returns the minimal set of properties for an appointment (similar to freebusy data)
 		 * @return array minimal properties for an appointment.
@@ -400,8 +447,6 @@
 				$properties["categories"] = "PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords";
 				$properties["last_modification_time"] = PR_LAST_MODIFICATION_TIME;
 				$properties["creation_time"] = PR_CREATION_TIME;
-				// Conflict properties
-				$properties["conflictitems"] = PR_CONFLICT_ITEMS;
 				$properties["deleted_on"] = PR_DELETED_ON;
 
 				// Detailed contacts properties
@@ -615,8 +660,6 @@
 				$properties["categories"] = "PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords";
 				$properties["sensitivity"] = PR_SENSITIVITY;
 				$properties["private"] = "PT_BOOLEAN:PSETID_Common:0x8506";
-				// Conflict properties
-				$properties["conflictitems"] = PR_CONFLICT_ITEMS;
 				$properties["creation_time"] = PR_CREATION_TIME;
 				$properties["deleted_on"] = PR_DELETED_ON;
 
@@ -837,11 +880,11 @@
 				$properties["flag_icon"] = PR_FLAG_ICON;
 				$properties["block_status"] = PR_BLOCK_STATUS;
 				$properties["reminder_time"] = "PT_SYSTIME:PSETID_Common:0x8502";
-				$properties["reminder_set"] = "PT_BOOLEAN:PSETID_Common:0x8503";
+				$properties["reminder"] = "PT_BOOLEAN:PSETID_Common:0x8503";
 				$properties["flag_request"] = "PT_STRING8:PSETID_Common:0x8530";
 				$properties["flag_due_by"] = "PT_SYSTIME:PSETID_Common:0x8560";
-				$properties["task_due_date"] = "PT_SYSTIME:PSETID_Task:0x8105";
-				$properties["task_start_date"] = "PT_SYSTIME:PSETID_Task:0x8104";
+				$properties["duedate"] = "PT_SYSTIME:PSETID_Task:0x8105";
+				$properties["startdate"] = "PT_SYSTIME:PSETID_Task:0x8104";
 				$properties["reply_requested"] = PR_REPLY_REQUESTED;
 				$properties["reply_time"] = PR_REPLY_TIME;
 				$properties["response_requested"] = PR_RESPONSE_REQUESTED;
@@ -850,7 +893,6 @@
 				$properties["read_receipt_requested"] = PR_READ_RECEIPT_REQUESTED;
 				$properties["categories"] = "PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords";
 				$properties["transport_message_headers"] = PR_TRANSPORT_MESSAGE_HEADERS;
-				$properties["x_original_to"] = "PT_STRING8:PS_INTERNET_HEADERS:x-original-to";
 				$properties["source_message_info"] = "PT_BINARY:PSETID_Common:0x85CE";
 				$properties["deferred_send_time"] = PR_DEFERRED_SEND_TIME;
 
@@ -864,9 +906,6 @@
 				$properties["appointment_enddate_recurring"] = "PT_SYSTIME:PSETID_Appointment:0x8236";		// ClipEnd
 				$properties["appointment_exception"] = "PT_BOOLEAN:PSETID_Meeting:0xA";						// LID_IS_EXCEPTION
 				$properties["appointment_location"] = "PT_STRING8:PSETID_Appointment:0x8208";
-				// Conflict properties
-				$properties["conflictitems"] = PR_CONFLICT_ITEMS;
-
 				// Propose new time properties
 				$properties["proposed_start_date"] = "PT_SYSTIME:PSETID_Appointment:0x8250";
 				$properties["proposed_end_date"] = "PT_SYSTIME:PSETID_Appointment:0x8251";
@@ -958,9 +997,6 @@
 				$properties["subject"] = PR_SUBJECT;
 				$properties["color"] = "PT_LONG:PSETID_Note:0x8B00";
 				$properties["categories"] = "PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords";
-				// Conflict properties
-				$properties["conflictitems"] = PR_CONFLICT_ITEMS;
-
 				$properties["deleted_on"] = PR_DELETED_ON;
 
 				$this->mapping[$this->storeMapping]['note'] = getPropIdsFromStrings($this->store, $properties);
@@ -1027,6 +1063,7 @@
 				$properties["commonstart"] = "PT_SYSTIME:PSETID_Common:0x8516";
 				$properties["commonend"] = "PT_SYSTIME:PSETID_Common:0x8517";
 				$properties["commonassign"] = "PT_LONG:PSETID_Common:0x8518";
+				$properties["flag_icon"] = PR_FLAG_ICON;
 				$properties["flag_due_by"] = "PT_SYSTIME:PSETID_Common:0x8560";
 				$properties["flag_status"] = PR_FLAG_STATUS;
 				$properties["flag_complete_time"] = PR_FLAG_COMPLETE_TIME;
@@ -1034,10 +1071,6 @@
 				$properties["recurring"] = "PT_BOOLEAN:PSETID_Task:0x8126";
 				$properties["recurring_data"] = "PT_BINARY:PSETID_Task:0x8116";
 				$properties["dead_occurrence"] = "PT_BOOLEAN:PSETID_Task:0x8109";
-
-				// Conflict properties
-				$properties["conflictitems"] = PR_CONFLICT_ITEMS;
-
 				$properties["deleted_on"] = PR_DELETED_ON;
 
 				$properties["sent_representing_entryid"] = PR_SENT_REPRESENTING_ENTRYID;
