@@ -129,14 +129,17 @@
 
 										if (isset($action["message_action"]["isSearchFolder"])
 											&& $action["message_action"]["isSearchFolder"]) {
-											$this->deleteSearchFolder($store, $parententryid, $entryid, $action);
+											$result = $this->deleteSearchFolder($store, $parententryid, $entryid, $action);
+											dump($result, '$result');
+											if ($result) {
+												$this->sendFeedback(true);
+											}
 										} else {
 											$this->removeFromFavorite($entryid);
 										}
 									} else {
 										$this->deleteFolder($store, $parententryid, $entryid, $action);
 									}
-
 								}
 								break;
 
@@ -260,12 +263,12 @@
 										$entryid = $GLOBALS["mapisession"]->removeUserStore($action["user_name"]);
 									} else {
 										$entryid = $GLOBALS["mapisession"]->getStoreEntryIdOfUser($action["user_name"]);
-										$this->removeFromFavorite(hex2bin($action["entryid"]), PR_WLINK_ENTRYID, false);
+										$this->removeFromFavorite(hex2bin($action["entryid"]), $store, PR_WLINK_ENTRYID, false);
 									}
 								} else {
 									// We're closing a Shared Store, simply remove it from the session.
 									$entryid = $GLOBALS["mapisession"]->removeUserStore($action["user_name"]);
-									$this->removeFromFavorite(hex2bin($action["store_entryid"]), PR_WLINK_STORE_ENTRYID, false);
+									$this->removeFromFavorite(hex2bin($action["store_entryid"]), $store, PR_WLINK_STORE_ENTRYID, false);
 								}
 
 								$data = array();
@@ -282,26 +285,51 @@
 							case "opensharedfolder":
 								$username = strtolower($action["user_name"]);
 								$store = $GLOBALS["mapisession"]->addUserStore($username);
-								if ($store) {
-									$options = array( $username => array( $action["folder_type"] => $action ));
-									$data = $GLOBALS["operations"]->getHierarchyList($this->list_properties, HIERARCHY_GET_ONE, $store, $options, $username);
-
-									// Check if we have obtained a store, and if that store has read access
-									if (!empty($data["item"][0]["folders"]["item"]) &&
-										// We expect multiple folders, as it should always return the IPM_SUBTREE 
-										// besides the actual opened folder
-										count($data["item"][0]["folders"]["item"]) > 1 && 
-										// Check the second folder as the first one is the IPM_SUBTREE
-										$data["item"][0]["folders"]["item"][1]["props"]["access"] !== 0) {
-										$this->addActionData("list", $data);
-									} else {
-										// Throw an exception that we couldn't open the shared store,
-										// lets have processException() fill in our error message.
-										throw new MAPIException(null, MAPI_E_NO_ACCESS);
-									}
-									$GLOBALS["bus"]->addData($this->getResponseData());
-									$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID,OBJECT_SAVE);
+								if (!$store) {
+									break;
 								}
+
+								$options = array( $username => array( $action["folder_type"] => $action ));
+								$data = $GLOBALS["operations"]->getHierarchyList($this->list_properties, HIERARCHY_GET_ONE, $store, $options, $username);
+
+								if (empty($data["item"][0]["folders"]["item"])) {
+									throw new MAPIException(null, MAPI_E_NO_ACCESS);
+								}
+
+								$folders = count($data["item"][0]["folders"]["item"]);
+								if ($folders === 0) {
+									throw new MAPIException(null, MAPI_E_NO_ACCESS);
+								}
+
+								$noPermissionFolders = array_filter($data['item'][0]['folders']['item'], function($item) {
+									return $item['props']['access'] === 0;
+								});
+								if (count($noPermissionFolders) >= $folders) {
+									// Throw an exception that we couldn't open the shared store,
+									// lets have processException() fill in our error message.
+									throw new MAPIException(null, MAPI_E_NO_ACCESS);
+								}
+
+								$this->addActionData("list", $data);
+								$GLOBALS["bus"]->addData($this->getResponseData());
+								$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID,OBJECT_SAVE);
+								break;
+							case "sharedstoreupdate":
+								$supported_types = ['inbox' => 1, 'all' => 1];
+								$users = $GLOBALS["settings"]->get("zarafa/v1/contexts/hierarchy/shared_stores", []);
+
+								foreach($users as $username => $data) {
+									$key = array_keys($data)[0];
+									$folder_type = $data[$key]['folder_type'];
+
+									if (!isset($supported_types[$folder_type])) {
+										continue;
+									}
+
+									$GLOBALS["bus"]->notify(REQUEST_ENTRYID, HIERARCHY_UPDATE, array($username, $folder_type));
+								}
+
+								$this->sendFeedback(true);
 								break;
 							default:
 								$this->handleUnknownActionType($actionType);
@@ -465,7 +493,7 @@
 		function addFolderToResponseData($store, $entryid, $actionType)
 		{
 			$folder = mapi_msgstore_openentry($store, $entryid);
-			$folderProps = mapi_folder_getprops($folder, $this->list_properties);
+			$folderProps = mapi_getprops($folder, $this->list_properties);
 
 			$data = $GLOBALS["operations"]->setFolder($folderProps);
 			$this->addActionData($actionType, $data);
@@ -661,11 +689,9 @@
 			// check if the folder is the default calendar, if so we also need to set the same permissions on the freebusy folder
 			$root = mapi_msgstore_openentry($store, null);
 			if($root) {
-				$rootProps = mapi_getprops($root, array(PR_IPM_APPOINTMENT_ENTRYID, PR_FREEBUSY_ENTRYIDS));
+				$rootProps = mapi_getprops($root, array(PR_IPM_APPOINTMENT_ENTRYID));
 				if ($folderProps[PR_ENTRYID] == $rootProps[PR_IPM_APPOINTMENT_ENTRYID]){
-					if(isset($rootProps[PR_FREEBUSY_ENTRYIDS]) && isset($rootProps[PR_FREEBUSY_ENTRYIDS][3])){
-						$freebusy = mapi_msgstore_openentry($store, $rootProps[PR_FREEBUSY_ENTRYIDS][3]);
-					}
+					$freebusy = freebusy::getLocalFreeBusyFolder($store);
 				}
 			}
 
@@ -777,40 +803,67 @@
 
 		/**
 		 * Remove favorites link message from associated contains table of IPM_COMMON_VIEWS.
+		 * It will also remove favorites search folders of given store.
 		 *
 		 * @param String $entryid entryid of the folder.
+		 * @param object $store MAPI object of the store
 		 * @param String $prop property which is used to find record from associated contains table of
 		 * IPM_COMMON_VIEWS folder.
 		 * @param Boolean $doNotify true to notify the IPM_COMMO_VIEWS folder on client side.
 		 */
-		function removeFromFavorite($entryid, $prop = PR_WLINK_ENTRYID, $doNotify = true)
+		function removeFromFavorite($entryid, $store = false, $prop = PR_WLINK_ENTRYID, $doNotify = true)
 		{
 			$commonViewsFolder = $this->getCommonViewsFolder();
 			$associatedTable = mapi_folder_getcontentstable($commonViewsFolder, MAPI_ASSOCIATED);
 
-			$restriction = array(RES_PROPERTY,
-				array(
-					RELOP => RELOP_EQ,
-					ULPROPTAG => PR_MESSAGE_CLASS,
-					VALUE => array(PR_MESSAGE_CLASS => "IPM.Microsoft.WunderBar.Link")
-				),
+			$restriction = Array(RES_OR,
+				Array(
+					array(RES_PROPERTY,
+						array(
+							RELOP => RELOP_EQ,
+							ULPROPTAG => PR_MESSAGE_CLASS,
+							VALUE => array(PR_MESSAGE_CLASS => "IPM.Microsoft.WunderBar.Link")
+						)
+					),
+					array(RES_PROPERTY,
+						array(
+							RELOP => RELOP_EQ,
+							ULPROPTAG => PR_MESSAGE_CLASS,
+							VALUE => array(PR_MESSAGE_CLASS => "IPM.Microsoft.WunderBar.SFInfo")
+						)
+					)
+				)
 			);
+			$finderHierarchyTables = array();
+			if (!empty($store)) {
+				$props = mapi_getprops($store, array(PR_FINDER_ENTRYID));
+				$finderFolder = mapi_msgstore_openentry($store, $props[PR_FINDER_ENTRYID]);
+				$hierarchyTable = mapi_folder_gethierarchytable($finderFolder, MAPI_DEFERRED_ERRORS);
+				$finderHierarchyTables[$props[PR_FINDER_ENTRYID]] = $hierarchyTable;
+			}
 
-			$messages = mapi_table_queryallrows($associatedTable, array(PR_ENTRYID, PR_WLINK_ENTRYID, PR_WLINK_STORE_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID), $restriction);
+			$messages = mapi_table_queryallrows($associatedTable, array(PR_ENTRYID, PR_MESSAGE_CLASS, PR_WB_SF_ID, PR_WLINK_ENTRYID, PR_WLINK_STORE_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID), $restriction);
 
 			if (!empty($messages)) {
 				foreach ($messages as $message) {
-					if ($GLOBALS['entryid']->compareEntryIds($message[$prop], $entryid)) {
-						mapi_folder_deletemessages($commonViewsFolder, array($message[PR_ENTRYID]));
-						if($doNotify) {
-							$GLOBALS["bus"]->notify(bin2hex($message[PR_ENTRYID]), OBJECT_SAVE, $message);
+					if ($message[PR_MESSAGE_CLASS] === "IPM.Microsoft.WunderBar.SFInfo" && !empty($finderHierarchyTables)) {
+						$props = $GLOBALS["operations"]->getFavoritesLinkedSearchFolderProps($message[PR_WB_SF_ID], $finderHierarchyTables);
+						if (!empty($props)) {
+							$this->deleteSearchFolder($store, $props[PR_PARENT_ENTRYID], $props[PR_ENTRYID], array());
 						}
-					} else {
-						$storeObj = $GLOBALS["mapisession"]->openMessageStore($message[PR_WLINK_STORE_ENTRYID]);
-						$storeProps = mapi_getprops($storeObj, array(PR_ENTRYID));
-						if ($GLOBALS['entryid']->compareEntryIds($message[PR_WLINK_ENTRYID], $storeProps[PR_ENTRYID])){
+					} else if ($message[PR_MESSAGE_CLASS] === "IPM.Microsoft.WunderBar.Link") {
+						if ($GLOBALS['entryid']->compareEntryIds($message[$prop], $entryid)) {
 							mapi_folder_deletemessages($commonViewsFolder, array($message[PR_ENTRYID]));
-							$this->sendFeedback(true);
+							if ($doNotify) {
+								$GLOBALS["bus"]->notify(bin2hex($message[PR_ENTRYID]), OBJECT_SAVE, $message);
+							}
+						} else {
+							$storeObj = $GLOBALS["mapisession"]->openMessageStore($message[PR_WLINK_STORE_ENTRYID]);
+							$storeProps = mapi_getprops($storeObj, array(PR_ENTRYID));
+							if ($GLOBALS['entryid']->compareEntryIds($message[PR_WLINK_ENTRYID], $storeProps[PR_ENTRYID])) {
+								mapi_folder_deletemessages($commonViewsFolder, array($message[PR_ENTRYID]));
+								$this->sendFeedback(true);
+							}
 						}
 					}
 				}
@@ -853,7 +906,6 @@
 				foreach ($messages as $message) {
 					if (bin2hex($message[PR_WB_SF_ID]) === $searchFolderId) {
 						mapi_folder_deletemessages($commonViewsFolder, array($message[PR_ENTRYID]));
-						$this->sendFeedback(true);
 					}
 				}
 			}
@@ -905,7 +957,7 @@
             // This flag indicates there is currently an open search tab which uses this search folder.
             if (!isset($action["message_action"]["keepSearchFolder"])) {
                 $finderFolder = mapi_msgstore_openentry($store, $parententryid);
-                mapi_folder_deletefolder($finderFolder, $entryid);
+                return mapi_folder_deletefolder($finderFolder, $entryid , DEL_FOLDERS | DEL_MESSAGES | DELETE_HARD_DELETE);
             } else {
                 // Rename search folder to default search folder name otherwise,
                 // It will not be picked up by our search folder cleanup logic.
@@ -913,7 +965,7 @@
                 $props = array();
                 $folder = mapi_msgstore_openentry($store, $storeProps[PR_FINDER_ENTRYID]);
                 $folderName = $GLOBALS["operations"]->checkFolderNameConflict($store, $folder, "WebApp Search Folder");
-                $GLOBALS["operations"]->renameFolder($store, $entryid, $folderName, $props);
+	            return $GLOBALS["operations"]->renameFolder($store, $entryid, $folderName, $props);
             }
 		}
 
@@ -1063,7 +1115,7 @@
 						// If destination folder is wastebasket then remove source folder from favorites list if
 						// it is present in it.
 						$defaultStore = $GLOBALS["mapisession"]->getDefaultMessageStore();
-						$wastebasketFolderEntryid = mapi_folder_getprops($defaultStore, array(PR_IPM_WASTEBASKET_ENTRYID));
+						$wastebasketFolderEntryid = mapi_getprops($defaultStore, array(PR_IPM_WASTEBASKET_ENTRYID));
 						if($GLOBALS["entryid"]->compareEntryIds($wastebasketFolderEntryid[PR_IPM_WASTEBASKET_ENTRYID], $destfolderentryid)) {
 							$this->removeFromFavorite($sourcefolderentryid);
 						}
@@ -1086,7 +1138,7 @@
 
 					// if move folder then refresh parent of source folder
 					$sourcefolder = mapi_msgstore_openentry($store, $parententryid);
-					$folderProps = mapi_folder_getprops($sourcefolder, array(PR_ENTRYID, PR_STORE_ENTRYID));
+					$folderProps = mapi_getprops($sourcefolder, array(PR_ENTRYID, PR_STORE_ENTRYID));
 					$GLOBALS["bus"]->notify(bin2hex($folderProps[PR_ENTRYID]), OBJECT_SAVE, $folderProps);
 				} else {
 					$this->sendFeedback(true);
@@ -1127,14 +1179,14 @@
 				if (is_array($subfolders)) {
 					foreach($subfolders as $subfolder) {
 						$folderObject = mapi_msgstore_openentry($deststore, $subfolder[PR_ENTRYID]); 
-						$folderProps = mapi_folder_getprops($folderObject, array(PR_ENTRYID, PR_STORE_ENTRYID));
+						$folderProps = mapi_getprops($folderObject, array(PR_ENTRYID, PR_STORE_ENTRYID));
 						$GLOBALS["bus"]->notify(bin2hex($subfolder[PR_ENTRYID]), OBJECT_SAVE, $folderProps);
 					}
 				}
 
 				// Now udpate destination folder
 				$folder = mapi_msgstore_openentry($deststore, $destfolderentryid);
-				$folderProps = mapi_folder_getprops($folder, array(PR_ENTRYID, PR_STORE_ENTRYID));
+				$folderProps = mapi_getprops($folder, array(PR_ENTRYID, PR_STORE_ENTRYID));
 				$GLOBALS["bus"]->notify(bin2hex($folderProps[PR_ENTRYID]), OBJECT_SAVE, $folderProps);
 			} else {
 				if ($moveFolder) {
