@@ -344,6 +344,7 @@
 							$e->setDisplayMessage($this->getOverQuotaMessage($store));
 						} else {
 							$e->setDisplayMessage(_("Could not save message") . ".");
+							$e->allowToShowDetailsMessage = true;
 						}
 						break;
 
@@ -399,6 +400,12 @@
 							$e->setDisplayMessage(_("Could not decline Task Request."));
 						break;
 				}
+				Log::Write(
+					LOGLEVEL_ERROR,
+					"itemmodule::handleException():". $actionType . ": " . $e->displayMessage,
+					$e,
+					$action
+				);
 			}
 
 			parent::handleException($e, $actionType, $store, $parententryid, $entryid, $action);
