@@ -1,15 +1,10 @@
 <?php
 include(BASE_PATH . 'server/includes/loader.php');
+include(BASE_PATH . 'server/includes/templates/serverinfo.php');
 
 $loader = new FileLoader();
 
-$version = trim(file_get_contents('version'));
-$versionInfo = array(
-	'webapp'	=> $version,
-	'zcp'		=> phpversion('mapi'),
-	'git'		=> DEBUG_LOADER === LOAD_SOURCE ? gitversion() : '',
-);
-
+$versionInfo['webapp'] = $loader->getVersion();
 $serverConfig = array(
 	'enable_plugins'				=> ENABLE_PLUGINS ? true : false,
 	'enable_advanced_settings'		=> ENABLE_ADVANCED_SETTINGS ? true : false,
@@ -17,6 +12,7 @@ $serverConfig = array(
 	'freebusy_load_start_offset'	=> FREEBUSY_LOAD_START_OFFSET,
 	'freebusy_load_end_offset' 		=> FREEBUSY_LOAD_END_OFFSET,
 	'client_timeout' 				=> defined('CLIENT_TIMEOUT') && is_numeric(CLIENT_TIMEOUT) && CLIENT_TIMEOUT>0 ? CLIENT_TIMEOUT : false,
+	'json_themes'					=> Theming::getJsonThemes(),
 	'active_theme'					=> Theming::getActiveTheme(),
 );
 ?>
@@ -24,7 +20,7 @@ $serverConfig = array(
 <html>
 
 	<head>
-		<meta name="Generator" content="Kopano WebApp v<?php echo $version?>">
+		<meta name="Generator" content="Kopano WebApp v<?php echo $loader->getVersion()?>">
 		<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
 		<meta http-equiv="X-UA-Compatible" content="IE=edge" />
 		<title><?php echo $webappTitle; ?></title>
@@ -35,7 +31,10 @@ $serverConfig = array(
 		<link rel="stylesheet" href="client/resources/css/external/login.css" >
 
 		<script type="text/javascript"><?php require(BASE_PATH . 'client/fingerprint.js'); ?></script>
-		<?php $loader->cssOrder(); ?>
+		<?php
+			$loader->cssOrder();
+			echo Theming::getStyles($theme);
+		?>
 	</head>
 
 	<body class="zarafa-welcome theme-<?php echo strtolower($theme ? $theme : 'basic') ?>">
@@ -45,7 +44,6 @@ $serverConfig = array(
 				<div id="content">
 					<div class="left">
 						<div id="logo"></div>
-						<h2>WebApp <?php echo $version; ?></h2>
 					</div>
 					<div class="right">
 					</div>
@@ -56,7 +54,7 @@ $serverConfig = array(
 		<script type="text/javascript"><?php require(BASE_PATH . 'client/resize.js'); ?></script>
 
 		<!-- Translations -->
-		<script type="text/javascript" src="index.php?version=<?php echo $version?>&load=translations.js&lang=<?php echo $Language->getSelected()?>"></script>
+		<script type="text/javascript" src="index.php?version=<?php echo $loader->getVersion() ?>&load=translations.js&lang=<?php echo $Language->getSelected()?>"></script>
 		<!-- JS Files -->
 		<?php $loader->jsOrder(); ?>
 
