@@ -260,20 +260,39 @@
 
 	/**
 	 * This function will encode the input string for the header based on the browser that makes the
-	 * HTTP request. MSIE has an issue with unicode filenames. All browsers do not seem to follow
-	 * the RFC specification. Firefox requires an unencoded string in the HTTP header. MSIE will
+	 * HTTP request. MSIE and Edge has an issue with unicode filenames. All browsers do not seem to follow
+	 * the RFC specification. Firefox requires an unencoded string in the HTTP header. MSIE and Edge will
 	 * break on this and requires encoding.
 	 * @param String $input Unencoded string
 	 * @return String Encoded string
 	 */
-	function browserDependingHTTPHeaderEncode($input){
-		if(strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') === false){
+	function browserDependingHTTPHeaderEncode($input)
+	{
+		if(!isIE11() && !isEdge()) {
 			return $input;
-		}else{
+		} else {
 			return rawurlencode($input);
 		}
 	}
 
+	/**
+	 * Helps to detect if the request came from IE11 or not.
+	 * @return Boolean True if IE11 is the requester, position of the word otherwise.
+	 */
+	function isIE11()
+	{
+		return strpos($_SERVER['HTTP_USER_AGENT'], 'Trident') !== false;
+	}
+
+	/**
+	 * Helps to detect if the request came from Edge or not.
+	 * @return Boolean True if Edge is the requester, position of the word otherwise.
+	 */
+	function isEdge()
+	{
+		return strpos($_SERVER['HTTP_USER_AGENT'], 'Edge') !== false;
+	}
+
 	/**
 	 * This function will return base name of the file from the full path of the file.
 	 * PHP's basename() does not properly support streams or filenames beginning with a non-US-ASCII character.
@@ -372,7 +391,6 @@
 	// Constants for regular expressions which are used in get method to verify the input string
 	define("ID_REGEX", "/^[a-z0-9_]+$/im");
 	define("STRING_REGEX", "/^[a-z0-9_\s()@]+$/im");
-	define("MAILTO_REGEX", "/^[a-z0-9_\s()@:.=&?!%]+$/im");
 	define("USERNAME_REGEX", "/^[a-z0-9\-\.\'_@]+$/im");
 	define("ALLOWED_EMAIL_CHARS_REGEX", "/^[-a-z0-9_\.@!#\$%&'\*\+\/\=\?\^_`\{\|\}~]+$/im");
 	define("NUMERIC_REGEX", "/^[0-9]+$/im");
@@ -561,16 +579,13 @@
 	}
 
 	/**
-	 * Fetches the full hierarchy and returns an array with a cache of the state
-	 * of the folders in the hierarchy.
-	 *
-	 * @return {Array} folderStatCache a cache of the hierarchy folders.
+	 * Tries to open the IPM subtree. If opening fails, it will try to fix it by
+	 * trying to find the correct entryid of the IPM subtree in the hierarchy.
+	 * @param {MAPIObject} $store the store to retrieve IPM subtree from
+	 * @return {mixed} false if the subtree is broken beyond quick repair,
+	 * the IPM subtree resource otherwise
 	 */
-	function update_hierarchy_counters()
-	{
-		$props = array(PR_DISPLAY_NAME, PR_LOCAL_COMMIT_TIME_MAX, PR_CONTENT_COUNT, PR_CONTENT_UNREAD, PR_ENTRYID, PR_STORE_ENTRYID);
-
-		$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
+	function getSubTree($store) {
 		$storeProps = mapi_getprops($store, array(PR_IPM_SUBTREE_ENTRYID));
 		try {
 			$ipmsubtree = mapi_msgstore_openentry($store, $storeProps[PR_IPM_SUBTREE_ENTRYID]);
@@ -578,12 +593,56 @@
 			if ($e->getCode() == MAPI_E_NOT_FOUND || $e->getCode() == MAPI_E_INVALID_ENTRYID) {
 				$username = $GLOBALS["mapisession"]->getUserName();
 				error_log(sprintf('Unable to open IPM_SUBTREE for %s, trying to correct PR_IPM_SUBTREE_ENTRYID', $username));
-				$ipmsbutree = fix_ipmsubtree($store);
+				$ipmsubtree = fix_ipmsubtree($store);
 			}
 		}
-		$hierarchy =  mapi_folder_gethierarchytable($ipmsubtree, CONVENIENT_DEPTH);
+
+		return $ipmsubtree;
+	}
+
+	/**
+	 * Fetches the full hierarchy and returns an array with a cache of the stat
+	 * of the folders in the hierarchy. Passing the folderType is required for cases where
+	 * the user has permission on the inbox folder, but no folder visible
+	 * rights on the rest of the store.
+	 *
+	 * @param {String} $username the user who's store to retrieve hierarchy counters from.
+	 * If no username is given, the currently logged in user's store will be used.
+	 * @param {String} $folderType if inbox use the inbox as root folder.
+	 * @return {Array} folderStatCache a cache of the hierarchy folders.
+	 */
+	function updateHierarchyCounters($username='', $folderType='')
+	{
+		// Open the correct store
+		if ($username) {
+			$userEntryid = $GLOBALS["mapisession"]->getStoreEntryIdOfUser($username);
+			$store = $GLOBALS["mapisession"]->openMessageStore($userEntryid);
+		} else {
+			$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
+		}
+
+		$props = array(PR_DISPLAY_NAME, PR_LOCAL_COMMIT_TIME_MAX, PR_CONTENT_COUNT, PR_CONTENT_UNREAD, PR_ENTRYID, PR_STORE_ENTRYID);
+
+		if ($folderType === 'inbox') {
+			try {
+				$rootFolder = mapi_msgstore_getreceivefolder($store);
+			} catch (MAPIException $e) {
+				$username = $GLOBALS["mapisession"]->getUserName();
+				error_log(sprintf("Unable to open Inbox for %s. MAPI Error '%s'", $username, get_mapi_error_name($e->getCode())));
+				return [];
+			}
+		} else {
+			$rootFolder = getSubTree($store);
+		}
+
+		$hierarchy = mapi_folder_gethierarchytable($rootFolder, CONVENIENT_DEPTH | MAPI_DEFERRED_ERRORS);
 		$rows = mapi_table_queryallrows($hierarchy, $props);
 
+		// Append the Inbox folder itself.
+		if ($folderType === 'inbox') {
+			array_push($rows, mapi_getprops($rootFolder, $props));
+		}
+
 		$folderStatCache = array();
 		foreach($rows as $folder) {
 			$folderStatCache[$folder[PR_DISPLAY_NAME]] = array(
@@ -603,7 +662,7 @@
 	 * by looking up the IPM_SUBTREE in the Hierarchytable and fetching the entryid
 	 * and if found, setting the PR_IPM_SUBTREE_ENTRYID to that found entryid.
 	 *
-	 * @param {Object} store the users MAPI Store
+	 * @param {Object} $store the users MAPI Store
 	 * @return {mixed} false if unable to correct otherwise return the subtree.
 	 */
 	function fix_ipmsubtree($store)
@@ -636,5 +695,57 @@
 
 		mapi_setprops($store, [PR_IPM_SUBTREE_ENTRYID => $entryid]);
 		error_log(sprintf('Fixed PR_IPM_SUBTREE_ENTRYID for %s', $username));
+
+		return $ipmsubtree;
+	}
+
+	/**
+	 * Helper function which provide protocol used by current request.
+	 * @return string It can be either https or http.
+	 */
+	function getRequestProtocol()
+	{
+		if(!empty($_SERVER['HTTP_X_FORWARDED_PROTO'])) {
+			return $_SERVER['HTTP_X_FORWARDED_PROTO'];
+		} else {
+			return !empty($_SERVER['HTTPS']) ? "https" : "http";
+		}
+	}
+
+	/**
+	 * Helper function which defines that webapp has to use secure cookies
+	 * or not. by default webapp always use secure cookies whether or not
+	 * 'INSECURE_COOKIES' defined. webapp only use insecure cookies
+	 * where a user has explicitly set true to 'INSECURE_COOKIES' configuration.
+	 *
+	 * @return Boolean return false only when a user has explicitly set
+	 * 'INSECURE_COOKIES' to true else returns true.
+	 */
+	function useSecureCookies()
+	{
+		return !defined('INSECURE_COOKIES') || INSECURE_COOKIES !== true;
+	}
+
+	/**
+	 * Check if the eml stream is corrupted or not
+	 * @param String $attachment Content fetched from PR_ATTACH_DATA_BIN property of an attachment.
+	 * @return True if eml is broken, false otherwise.
+	 */
+	function isBrokenEml($attachment)
+	{
+		// Get header part to process further
+		$splittedContent = preg_split("/\r?\n\r?\n/", $attachment);
+
+		// Fetch raw header
+		if (preg_match_all('/([^\n^:]+:)/', $splittedContent[0], $matches)) {
+			$rawHeaders = $matches[1];
+		}
+
+		// Compare if necessary headers are present or not
+		if (isset($rawHeaders) && in_array('From:', $rawHeaders) && in_array('Date:', $rawHeaders)) {
+			return false;
+		}
+
+		return true;
 	}
 ?>
